@@ -3,7 +3,7 @@ package Specio::Constraint::Parameterizable;
 use strict;
 use warnings;
 
-our $VERSION = '0.12';
+our $VERSION = '0.13';
 
 use Carp qw( confess );
 use Role::Tiny::With;
@@ -86,6 +86,10 @@ sub parameterize {
             = $self->_parameterized_constraint_generator()->($parameter);
     }
     else {
+        confess
+            'The "of" parameter passed to ->parameterize() must be an inlinable constraint if the parameterizable type has an inline_generator'
+            unless $parameter->can_be_inlined;
+
         my $ig = $self->_parameterized_inline_generator();
         $p{inline_generator} = sub { $ig->( shift, $parameter, @_ ) };
     }
@@ -103,13 +107,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Specio::Constraint::Parameterizable - A class which represents parameterizable constraints
 
 =head1 VERSION
 
-version 0.12
+version 0.13
 
 =head1 SYNOPSIS
 
@@ -174,13 +180,20 @@ new L<Specio::DeclaredAt> object is creating using a call stack depth of 1.
 
 This method returns a new L<Specio::Constraint::Parameterized> object.
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|http://rt.cpan.org/Public/Dist/Display.html?Name=Specio>
+(or L<bug-specio@rt.cpan.org|mailto:bug-specio@rt.cpan.org>).
+
+I am also usually active on IRC as 'drolsky' on C<irc://irc.perl.org>.
+
 =head1 AUTHOR
 
 Dave Rolsky <autarch@urth.org>
 
-=head1 COPYRIGHT AND LICENSE
+=head1 COPYRIGHT AND LICENCE
 
-This software is Copyright (c) 2015 by Dave Rolsky.
+This software is Copyright (c) 2016 by Dave Rolsky.
 
 This is free software, licensed under:
 
