@@ -3,7 +3,7 @@ package Specio::Constraint::Role::Interface;
 use strict;
 use warnings;
 
-our $VERSION = '0.12';
+our $VERSION = '0.13';
 
 use Carp qw( confess );
 use Class::Method::Modifiers ();
@@ -33,42 +33,35 @@ use overload(
     my $attrs = {
         %{$role_attrs},
         name => {
-            is        => 'bare',
             isa       => 'Str',
             predicate => '_has_name',
         },
         parent => {
-            is        => 'bare',
             does      => 'Specio::Constraint::Role::Interface',
             predicate => '_has_parent',
         },
         _constraint => {
-            is        => 'bare',
             isa       => 'CodeRef',
             init_arg  => 'constraint',
             predicate => '_has_constraint',
         },
         _optimized_constraint => {
-            is       => 'bare',
             isa      => 'CodeRef',
             init_arg => undef,
             lazy     => 1,
             builder  => '_build_optimized_constraint',
         },
         _ancestors => {
-            is       => 'bare',
             isa      => 'ArrayRef',
             init_arg => undef,
             lazy     => 1,
             builder  => '_build_ancestors',
         },
         _message_generator => {
-            is       => 'bare',
             isa      => 'CodeRef',
             init_arg => undef,
         },
         _coercions => {
-            is      => 'bare',
             builder => '_build_coercions',
         },
 
@@ -76,7 +69,6 @@ use overload(
         # objects. Because type names can be reused between packages (no global
         # registry) we can't compare types based on name either.
         _signature => {
-            is       => 'bare',
             isa      => 'Str',
             init_arg => undef,
             lazy     => 1,
@@ -506,13 +498,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Specio::Constraint::Role::Interface - The interface all type constraints should provide
 
 =head1 VERSION
 
-version 0.12
+version 0.13
 
 =head1 DESCRIPTION
 
@@ -533,13 +527,20 @@ or expanded upon.
 
 This role does the L<Specio::Role::Inlinable> role.
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|http://rt.cpan.org/Public/Dist/Display.html?Name=Specio>
+(or L<bug-specio@rt.cpan.org|mailto:bug-specio@rt.cpan.org>).
+
+I am also usually active on IRC as 'drolsky' on C<irc://irc.perl.org>.
+
 =head1 AUTHOR
 
 Dave Rolsky <autarch@urth.org>
 
-=head1 COPYRIGHT AND LICENSE
+=head1 COPYRIGHT AND LICENCE
 
-This software is Copyright (c) 2015 by Dave Rolsky.
+This software is Copyright (c) 2016 by Dave Rolsky.
 
 This is free software, licensed under:
 
