@@ -3,29 +3,25 @@ package Specio::DeclaredAt;
 use strict;
 use warnings;
 
-our $VERSION = '0.12';
+our $VERSION = '0.13';
 
 use Specio::OO;
 
 {
     my $attrs = {
         package => {
-            is       => 'bare',
             isa      => 'Str',
             required => 1,
         },
         filename => {
-            is       => 'bare',
             isa      => 'Str',
             required => 1,
         },
         line => {
-            is       => 'bare',
             isa      => 'Int',
             required => 1,
         },
         subroutine => {
-            is        => 'bare',
             isa       => 'Str',
             predicate => 'has_subroutine',
         },
@@ -75,13 +71,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Specio::DeclaredAt - A class to represent where a type or coercion was declared
 
 =head1 VERSION
 
-version 0.12
+version 0.13
 
 =head1 SYNOPSIS
 
@@ -122,13 +120,20 @@ Returns true if there is a subroutine name associated with this object.
 Puts all the information together into a single string like "declared in
 package Foo::Bar (.../Foo/Bar.pm) at line 42 in sub named blah".
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|http://rt.cpan.org/Public/Dist/Display.html?Name=Specio>
+(or L<bug-specio@rt.cpan.org|mailto:bug-specio@rt.cpan.org>).
+
+I am also usually active on IRC as 'drolsky' on C<irc://irc.perl.org>.
+
 =head1 AUTHOR
 
 Dave Rolsky <autarch@urth.org>
 
-=head1 COPYRIGHT AND LICENSE
+=head1 COPYRIGHT AND LICENCE
 
-This software is Copyright (c) 2015 by Dave Rolsky.
+This software is Copyright (c) 2016 by Dave Rolsky.
 
 This is free software, licensed under:
 
