@@ -10,7 +10,7 @@ use List::Util 1.33 ();
 use overload ();
 use re qw( is_regexp );
 
-our $VERSION = '0.12';
+our $VERSION = '0.13';
 
 use Scalar::Util ();
 use Specio::Constraint::Parameterizable;
@@ -380,13 +380,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Specio::Library::Builtins - Implements type constraint objects for Perl's built-in types
 
 =head1 VERSION
 
-version 0.12
+version 0.13
 
 =head1 DESCRIPTION
 
@@ -395,13 +397,20 @@ implements.
 
 This library uses L<Specio::Exporter> to export its types.
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|http://rt.cpan.org/Public/Dist/Display.html?Name=Specio>
+(or L<bug-specio@rt.cpan.org|mailto:bug-specio@rt.cpan.org>).
+
+I am also usually active on IRC as 'drolsky' on C<irc://irc.perl.org>.
+
 =head1 AUTHOR
 
 Dave Rolsky <autarch@urth.org>
 
-=head1 COPYRIGHT AND LICENSE
+=head1 COPYRIGHT AND LICENCE
 
-This software is Copyright (c) 2015 by Dave Rolsky.
+This software is Copyright (c) 2016 by Dave Rolsky.
 
 This is free software, licensed under:
 
